@@ -16,7 +16,7 @@ try:
 except ImportError:
     from .compat import cached_property
 
-from .config import CommandConfig
+from .config import CommandConfig, DEFAULT_CONFIG
 from .error_handling import ErrorHandler, NullErrorHandler, extended_error_handler
 from .exceptions import NoActiveContext
 from .utils import Bool, _NotSet, Terminal
@@ -265,11 +265,18 @@ class ContextProxy:
         return get_current_context().__exit__(exc_type, exc_val, exc_tb)
 
     @property
-    def terminal_width(self):
+    def terminal_width(self) -> int:
         try:
             return get_current_context().terminal_width
         except NoActiveContext:
             return _TERMINAL.width
 
+    @property
+    def config(self) -> CommandConfig:
+        try:
+            return get_current_context().config
+        except NoActiveContext:
+            return DEFAULT_CONFIG
+
 
 ctx: Context = cast(Context, ContextProxy())
